Skip to contents

Calculate an interval

Usage

ci(x, level = 95)

Arguments

x

A numeric vector.

level

The interval level as a numeric vector with values in the range \([0, 100]\). Defaults to 95 for the 95% interval.

Value

A numeric vector of the same length as level.