See daedalus::get_costs() for more information.
Arguments
- l
A list of
<daedalus_output>objects; each object will be passed todaedalus::get_costs().- names
A character vector, intended to apply to elements of
l.
See daedalus::get_costs() for more information.
A list of <daedalus_output> objects; each object will be passed to
daedalus::get_costs().
A character vector, intended to apply to elements of l.