Get epidemiological curves from model data
Usage
get_epicurve_data(dt, disease_tags = "default", format = c("long", "wide"))Arguments
- dt
A
<data.table>resulting fromrun_scenarios().A character vector giving names for replicates within each scenario.
- format
A string for whether the data should be returned in
"long"or"wide"format. Returning a 'wide' data.frame is only recommended when there is a small number ofdisease_tags, typically a triplet of "low", "medium", and "high" risk scenarios.