Skip to contents

Get incidence data from a list of model outputs

Usage

get_epidata_list(l, names)

Arguments

l

A list of <daedalus_output> objects; each object will be passed to daedalus::get_costs().

names

A character vector, intended to apply to elements of l.

Value

A <data.table>.