Skip to contents

Get epidemic summary data from a list of model outputs

Usage

get_summary_list(l, names, ...)

Arguments

l

A list of <daedalus_output> objects; each object will be passed to daedalus::get_costs().

names

A character vector, intended to apply to elements of l.

...

Additional arguments passed to daedalus::get_epidemic_summary().

Value

A <data.table>.