R/scenario_helpers.R
ci.Rd
Calculate an interval
ci(x, level = 95)
A numeric vector.
The interval level as a numeric vector with values in the range \([0, 100]\). Defaults to 95 for the 95% interval.
95
A numeric vector of the same length as level.
level