Get incidence data from a list of model outputs
Arguments
- l
A list of
<daedalus_output>objects; each object will be passed todaedalus::get_costs().- names
A character vector, intended to apply to elements of
l.
Get incidence data from a list of model outputs
A list of <daedalus_output> objects; each object will be passed to
daedalus::get_costs().
A character vector, intended to apply to elements of l.