Get epidemic summary data from a list of model outputs
Source:R/scenario_helpers.R
get_summary_list.RdGet epidemic summary data from a list of model outputs
Arguments
- l
A list of
<daedalus_output>objects; each object will be passed todaedalus::get_costs().- names
A character vector, intended to apply to elements of
l.- ...
Additional arguments passed to
daedalus::get_epidemic_summary().