Run multiple DAEDALUS scenarios
Usage
run_scenarios(
country,
infection,
response_strategy = NULL,
time_end = 100,
initial_state_manual = NULL
)Arguments
- country
A country or territory object of class
<daedalus_country>, or a country or territory name from those included in the package; see daedalus.data::country_names, or a country ISO2 or ISO3 code; see daedalus.data::country_codes_iso2c and daedalus.data::country_codes_iso3c. Country-specific data such as the community and workplace contacts, the demography, and the distribution of the workforce into economic sectors is automatically accessed from package data for the relevant country name if it is passed as a string. To override package defaults for country characteristics, pass a<daedalus_country>object instead. Seedaedalus_country()for more.- infection
A list of
<daedalus_infection>objects. Must have a minimum length of 2.- response_strategy
A time-limited response strategy specified as a single
<daedalus_npi>created usingdaedalus::daedalus_timed_npi(), or a list of such objects, orNULLfor no response. Lists may includeNULL, which is useful when comparing response scenarios against the no-response counterfactual. If a list is passed, all elements must be named, or the list may have no names, in which case synthetic names will be assigned and a message printed to screen. Lists with some elements named and some unnamed are not accepted.- time_end
A vector of integer-ish numbers giving the durations over which to run scenarios. Each scenario is run for each
time_end. The intention is to be able to run response scenarios for different durations, to be able to generate a time-series of how different costs accumulate.- initial_state_manual
An optional named list with the names
p_infectious,p_asymptomatic, andp_immune.p_infectiousandp_asymptomaticgive the proportion of infectious and symptomatic individuals in each age group and economic sector. Defaults to1e-6and0.0respectively.p_immunemay be a single number in the range0.0 <= p_immune <= 1.0or a 4-element vector in that range (the number of age groups in the model), for the proportion of individuals in the population or in each age group that have some pre-existing immunity to infection (reduced susceptibility). See Details for more.